@@ -1,13 +1,12 @@
-# @(#)$Ident: List.pm 2013-06-09 15:52 pjf ;
+# @(#)$Ident: List.pm 2013-09-13 17:45 pjf ;
 
 package File::DataClass::List;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.25.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.26.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
+use File::DataClass::Types  qw( ArrayRef Bool HashRef Result Undef );
 use Moo;
-use Unexpected::Types       qw( ArrayRef Bool HashRef Undef );
-use File::DataClass::Types  qw( Result );
 
 has 'found'  => is => 'ro', isa => Bool,     default => 0;
 has 'labels' => is => 'ro', isa => HashRef,  default => sub { return {} };
@@ -26,7 +25,7 @@ File::DataClass::List - List response class
 
 =head1 Version
 
-This document describes version v0.25.$Rev: 1 $
+This document describes version v0.26.$Rev: 1 $
 
 =head1 Synopsis
 
